==============================
:code:`Trakt['users/*/lists']`
==============================

.. automodule:: trakt.interfaces.users.lists

  .. autoclass:: UsersListsInterface
    :members: create, get
    :undoc-members:
